require 'rack'
require 'rack/server'
require 'json'

##
# Simulates two policies available on the network. One allows all requests, the other, denies all requests.
# Used for testing the access manager model with both the stub and service registry providers
##
class StubPolicies

  def self.call(env)
    request = Rack::Request.new env
    case request.path
    when '/allow'
      [200, {"Context-Type" => "application/json"}, [{ 'status' => 'success', 'data' => { 'allowed' => true, 'detail' => '', 'idm' => nil, 'rule_set' => 'allow all', 'notifications' => ['Policy approved authorization request'] }}.to_json]]
    when '/deny'
      [200, {"Context-Type" => "application/json"}, [{ 'status' => 'success', 'data' => { 'allowed' => false, 'detail' => '', 'idm' => nil, 'rule_set' => 'allow all', 'notifications' => ['Policy rejected authorization request'] }}.to_json]]
    else
      [200, {"Context-Type" => "application/json"}, [{ 'status' => 'success', 'data' => { 'notifications' => ['No policy associated with service'] }}.to_json]]
    end

  end
end

class PrintPolicies
  def self.call(env)
    request = Rack::Request.new env
    [200, {"Context-Type" => "application/json"}, [{
      "is a post request?" => request.post?,
      "request path" => request.path,
      "request params" => request.params
    }.to_json]]
  end
end

Rack::Server.start :app => StubPolicies
#Rack::Server.start :app => PrintPolicies
